# unfolding-viz
## Установка
> pip install unfolding-viz
## Описание
Библиотека, основанная на [pm4py-pn-unfoldings](https://github.com/TimurTimergalin/Unfoldings), для создания 
интерактивных визуализаций разверток сетей Петри
## Пример использования
Чтобы создать визуализацию, используется функция `visualize`. Пример её использования можно найти в *example.py*.